@@ -5,28 +5,30 @@ class VkAddonError(Exception):
 		self.text = text
 
 class VkAddon:
-	def __init__(self, event=None, member_id=None, on=True):
+	def __init__(self, event=None, on=True):
 		self.event = event
-		self.member_id = member_id
 
 	def connect(self):
-		if self.event == None or self.member_id == None:
-			raise VkAddonError('Не указан "event" или "member_id"')
+		if self.event == None:
+			raise VkAddonError('Не указан "event"')
 
 		else:
 			pass
 
 	def type(self):
 		try:
-			if self.member_id > 0:
+			if self.event['object']['from_id'] > 0:
 				if self.event['object']['action']['type'] == 'chat_invite_user':
 					return 'chat_invite_user'
 
+				if self.event['object']['action']['type'] == 'chat_invite_user_by_link':
+					return 'chat_invite_user_by_link'
+
 				elif self.event['object']['action']['type'] == 'chat_kick_user':
 					return 'chat_kick_user'
 
 				else:
-					return None
+					return self.event['object']['action']['type']
 
 		except KeyError:
 			if self.event['type'] == 'message_new':				
@@ -37,7 +39,16 @@ class VkAddon:
 
 
 	def member(self):
+		return self.event['object']['action']['member_id']
+
+	def from_id(self):
 		return self.event['object']['from_id']
 
+	def peer_id(self):
+		return self.event['object']['peer_id']
+
+	def text(self):
+		return self.event['object']['text']
+
 
 
